@@ -20,9 +20,11 @@
 
 # pylint: disable=W0511
 
+import tokenize
+
 import re
 
-from pylint.interfaces import IRawChecker
+from pylint.interfaces import IRawChecker, ITokenChecker
 from pylint.checkers import BaseChecker
 from pylint.utils import OPTION_RGX, MessagesHandlerMixIn
 
@@ -69,7 +71,7 @@ class EncodingChecker(BaseChecker):
     * encoding issues.
     """
 
-    __implements__ = IRawChecker
+    __implements__ = (IRawChecker, ITokenChecker)
 
     # configuration section name
     name = "miscellaneous"
@@ -103,51 +105,10 @@ class EncodingChecker(BaseChecker):
         ),
     )
 
-    def _check_note(self, notes, lineno, line, module_last_lineno):
-        """
-        Add the message 'fixme' in case a note is found in the line.
-
-        :param notes: regular expression object matching any notes
-                      (XXX, TODO, FIXME) behind a '#'
-        :type notes: re.pattern object
-        :param lineno: line number
-        :type lineno: int
-        :param line: line to be checked
-        :type line: str
-        :param module_last_lineno: last line number of the module as parsed by astroid
-                                   (may be different from real last line number in case
-                                    commented lines exist at the end of the module)
-        :type module_last_lineno: int
-        """
-        match = notes.search(line)
-        if not match:
-            return
-        # In case the module ends with commented lines, the astroid parser
-        # don't take into account those lines, then:
-        # - the line number of those lines is greater than the
-        #   module last line number (module.tolineno)
-        # - astroid module object can't inform pylint
-        #   of disabled messages in those extra lines.
-        if lineno > module_last_lineno:
-            disable_option_match = OPTION_RGX.search(line)
-            if disable_option_match:
-                try:
-                    _, value = disable_option_match.group(1).split("=", 1)
-                    values = [_val.strip().upper() for _val in value.split(",")]
-                    if set(values) & set(self.config.notes):
-                        return
-                except ValueError:
-                    self.add_message(
-                        "bad-inline-option",
-                        args=disable_option_match.group(1).strip(),
-                        line=line,
-                    )
-                    return
-        self.add_message(
-            "fixme",
-            args=line[match.start(1) :].rstrip(),
-            line=lineno,
-            col_offset=match.start(1),
+    def open(self):
+        super().open()
+        self._fixme_pattern = re.compile(
+            r"#\s*(%s)\b" % "|".join(map(re.escape, self.config.notes)), re.I
         )
 
     def _check_encoding(self, lineno, line, file_encoding):
@@ -167,15 +128,7 @@ class EncodingChecker(BaseChecker):
                 )
 
     def process_module(self, module):
-        """inspect the source file to find encoding problem or fixmes like
-        notes
-        """
-        if self.config.notes:
-            notes = re.compile(
-                r"#\s*(%s)\b" % "|".join(map(re.escape, self.config.notes)), re.I
-            )
-        else:
-            notes = None
+        """inspect the source file to find encoding problem"""
         if module.file_encoding:
             encoding = module.file_encoding
         else:
@@ -183,9 +136,44 @@ class EncodingChecker(BaseChecker):
 
         with module.stream() as stream:
             for lineno, line in enumerate(stream):
-                line = self._check_encoding(lineno + 1, line, encoding)
-                if line is not None and notes:
-                    self._check_note(notes, lineno + 1, line, module.tolineno)
+                self._check_encoding(lineno + 1, line, encoding)
+
+    def process_tokens(self, tokens):
+        """inspect the source to find fixme problems"""
+        if not self.config.notes:
+            return
+        comments = (
+            token_info for token_info in tokens if token_info.type == tokenize.COMMENT
+        )
+        for comment in comments:
+            comment_text = comment.string[1:].lstrip()  # trim '#' and whitespaces
+
+            # handle pylint disable clauses
+            disable_option_match = OPTION_RGX.search(comment_text)
+            if disable_option_match:
+                try:
+                    _, value = disable_option_match.group(1).split("=", 1)
+                    values = [_val.strip().upper() for _val in value.split(",")]
+                    if set(values) & set(self.config.notes):
+                        continue
+                except ValueError:
+                    self.add_message(
+                        "bad-inline-option",
+                        args=disable_option_match.group(1).strip(),
+                        line=comment.string,
+                    )
+                    continue
+
+            # emit warnings if necessary
+            match = self._fixme_pattern.search("#" + comment_text.lower())
+            if match:
+                note = match.group(1)
+                self.add_message(
+                    "fixme",
+                    col_offset=comment.string.lower().index(note.lower()),
+                    args=comment_text,
+                    line=comment.start[0],
+                )
 
 
 def register(linter):
