@@ -24,20 +24,22 @@ import re
 
 try:
     import enchant
-    from enchant.tokenize import (get_tokenizer,
-                                  Chunker,
-                                  Filter,
-                                  EmailFilter,
-                                  URLFilter,
-                                  WikiWordFilter)
+    from enchant.tokenize import (  # type: ignore
+        get_tokenizer,
+        Chunker,
+        Filter,
+        EmailFilter,
+        URLFilter,
+        WikiWordFilter,
+    )
 except ImportError:
     enchant = None
-    # pylint: disable=old-style-class,no-init
-    class Filter:
+    # pylint: disable=no-init
+    class Filter:  # type: ignore
         def _skip(self, word):
             raise NotImplementedError
 
-    class Chunker:
+    class Chunker:  # type: ignore
         pass
 
 
@@ -48,13 +50,13 @@ from pylint.checkers.utils import check_messages
 if enchant is not None:
     br = enchant.Broker()
     dicts = br.list_dicts()
-    dict_choices = [''] + [d[0] for d in dicts]
+    dict_choices = [""] + [d[0] for d in dicts]
     dicts = ["%s (%s)" % (d[0], d[1].name) for d in dicts]
     dicts = ", ".join(dicts)
     instr = ""
 else:
     dicts = "none"
-    dict_choices = ['']
+    dict_choices = [""]
     instr = " To make it working install python-enchant package."
 
 
@@ -74,8 +76,9 @@ class WordsWithUnderscores(Filter):
 
     They are probably function parameter names.
     """
+
     def _skip(self, word):
-        return '_' in word
+        return "_" in word
 
 
 class CamelCasedWord(Filter):
@@ -108,86 +111,123 @@ class SphinxDirectives(Filter):
 
 
 class ForwardSlashChunkder(Chunker):
-    '''
+    """
     This chunker allows splitting words like 'before/after' into 'before' and 'after'
-    '''
+    """
+
     def next(self):
         while True:
             if not self._text:
                 raise StopIteration()
-            if '/' not in self._text:
+            if "/" not in self._text:
                 text = self._text
                 self._offset = 0
-                self._text = ''
+                self._text = ""
                 return (text, 0)
-            pre_text, post_text = self._text.split('/', 1)
+            pre_text, post_text = self._text.split("/", 1)
             self._text = post_text
             self._offset = 0
-            if not pre_text or not post_text or \
-                    not pre_text[-1].isalpha() or not post_text[0].isalpha():
-                self._text = ''
+            if (
+                not pre_text
+                or not post_text
+                or not pre_text[-1].isalpha()
+                or not post_text[0].isalpha()
+            ):
+                self._text = ""
                 self._offset = 0
-                return (pre_text + '/' + post_text, 0)
+                return (pre_text + "/" + post_text, 0)
             return (pre_text, 0)
 
     def _next(self):
         while True:
-            if '/' not in self._text:
+            if "/" not in self._text:
                 return (self._text, 0)
-            pre_text, post_text = self._text.split('/', 1)
+            pre_text, post_text = self._text.split("/", 1)
             if not pre_text or not post_text:
                 break
             if not pre_text[-1].isalpha() or not post_text[0].isalpha():
                 raise StopIteration()
-            self._text = pre_text + ' ' + post_text
+            self._text = pre_text + " " + post_text
         raise StopIteration()
 
 
 class SpellingChecker(BaseTokenChecker):
     """Check spelling in comments and docstrings"""
+
     __implements__ = (ITokenChecker, IAstroidChecker)
-    name = 'spelling'
+    name = "spelling"
     msgs = {
-        'C0401': ('Wrong spelling of a word \'%s\' in a comment:\n%s\n'
-                  '%s\nDid you mean: \'%s\'?',
-                  'wrong-spelling-in-comment',
-                  'Used when a word in comment is not spelled correctly.'),
-        'C0402': ('Wrong spelling of a word \'%s\' in a docstring:\n%s\n'
-                  '%s\nDid you mean: \'%s\'?',
-                  'wrong-spelling-in-docstring',
-                  'Used when a word in docstring is not spelled correctly.'),
-        'C0403': ('Invalid characters %r in a docstring',
-                  'invalid-characters-in-docstring',
-                  'Used when a word in docstring cannot be checked by enchant.'),
-        }
-    options = (('spelling-dict',
-                {'default' : '', 'type' : 'choice', 'metavar' : '<dict name>',
-                 'choices': dict_choices,
-                 'help' : 'Spelling dictionary name. '
-                          'Available dictionaries: %s.%s.' % (dicts, instr)}),
-               ('spelling-ignore-words',
-                {'default' : '',
-                 'type' : 'string',
-                 'metavar' : '<comma separated words>',
-                 'help' : 'List of comma separated words that '
-                          'should not be checked.'}),
-               ('spelling-private-dict-file',
-                {'default' : '',
-                 'type' : 'string',
-                 'metavar' : '<path to file>',
-                 'help' : 'A path to a file that contains private '
-                          'dictionary; one word per line.'}),
-               ('spelling-store-unknown-words',
-                {'default' : 'n', 'type' : 'yn', 'metavar' : '<y_or_n>',
-                 'help' : 'Tells whether to store unknown words to '
-                          'indicated private dictionary in '
-                          '--spelling-private-dict-file option instead of '
-                          'raising a message.'}),
-               ('max-spelling-suggestions',
-                {'default': 4, 'type': 'int', 'metavar': 'N',
-                 'help': 'Limits count of emitted suggestions for '
-                         'spelling mistakes.'}),
-              )
+        "C0401": (
+            "Wrong spelling of a word '%s' in a comment:\n%s\n"
+            "%s\nDid you mean: '%s'?",
+            "wrong-spelling-in-comment",
+            "Used when a word in comment is not spelled correctly.",
+        ),
+        "C0402": (
+            "Wrong spelling of a word '%s' in a docstring:\n%s\n"
+            "%s\nDid you mean: '%s'?",
+            "wrong-spelling-in-docstring",
+            "Used when a word in docstring is not spelled correctly.",
+        ),
+        "C0403": (
+            "Invalid characters %r in a docstring",
+            "invalid-characters-in-docstring",
+            "Used when a word in docstring cannot be checked by enchant.",
+        ),
+    }
+    options = (
+        (
+            "spelling-dict",
+            {
+                "default": "",
+                "type": "choice",
+                "metavar": "<dict name>",
+                "choices": dict_choices,
+                "help": "Spelling dictionary name. "
+                "Available dictionaries: %s.%s." % (dicts, instr),
+            },
+        ),
+        (
+            "spelling-ignore-words",
+            {
+                "default": "",
+                "type": "string",
+                "metavar": "<comma separated words>",
+                "help": "List of comma separated words that " "should not be checked.",
+            },
+        ),
+        (
+            "spelling-private-dict-file",
+            {
+                "default": "",
+                "type": "string",
+                "metavar": "<path to file>",
+                "help": "A path to a file that contains private "
+                "dictionary; one word per line.",
+            },
+        ),
+        (
+            "spelling-store-unknown-words",
+            {
+                "default": "n",
+                "type": "yn",
+                "metavar": "<y_or_n>",
+                "help": "Tells whether to store unknown words to "
+                "indicated private dictionary in "
+                "--spelling-private-dict-file option instead of "
+                "raising a message.",
+            },
+        ),
+        (
+            "max-spelling-suggestions",
+            {
+                "default": 4,
+                "type": "int",
+                "metavar": "N",
+                "help": "Limits count of emitted suggestions for " "spelling mistakes.",
+            },
+        ),
+    )
 
     def open(self):
         self.initialized = False
@@ -199,7 +239,9 @@ class SpellingChecker(BaseTokenChecker):
         if not dict_name:
             return
 
-        self.ignore_list = [w.strip() for w in self.config.spelling_ignore_words.split(",")]
+        self.ignore_list = [
+            w.strip() for w in self.config.spelling_ignore_words.split(",")
+        ]
         # "param" appears in docstring in param description and
         # "pylint" appears in comments in pylint pragmas.
         self.ignore_list.extend(["param", "pylint"])
@@ -207,28 +249,33 @@ class SpellingChecker(BaseTokenChecker):
         # Expand tilde to allow e.g. spelling-private-dict-file = ~/.pylintdict
         if self.config.spelling_private_dict_file:
             self.config.spelling_private_dict_file = os.path.expanduser(
-                self.config.spelling_private_dict_file)
+                self.config.spelling_private_dict_file
+            )
 
         if self.config.spelling_private_dict_file:
             self.spelling_dict = enchant.DictWithPWL(
-                dict_name, self.config.spelling_private_dict_file)
-            self.private_dict_file = open(
-                self.config.spelling_private_dict_file, "a")
+                dict_name, self.config.spelling_private_dict_file
+            )
+            self.private_dict_file = open(self.config.spelling_private_dict_file, "a")
         else:
             self.spelling_dict = enchant.Dict(dict_name)
 
         if self.config.spelling_store_unknown_words:
             self.unknown_words = set()
 
-        self.tokenizer = get_tokenizer(dict_name,
-                                       chunkers=[ForwardSlashChunkder],
-                                       filters=[EmailFilter,
-                                                URLFilter,
-                                                WikiWordFilter,
-                                                WordsWithDigigtsFilter,
-                                                WordsWithUnderscores,
-                                                CamelCasedWord,
-                                                SphinxDirectives])
+        self.tokenizer = get_tokenizer(
+            dict_name,
+            chunkers=[ForwardSlashChunkder],
+            filters=[
+                EmailFilter,
+                URLFilter,
+                WikiWordFilter,
+                WordsWithDigigtsFilter,
+                WordsWithUnderscores,
+                CamelCasedWord,
+                SphinxDirectives,
+            ],
+        )
         self.initialized = True
 
     def close(self):
@@ -237,7 +284,7 @@ class SpellingChecker(BaseTokenChecker):
 
     def _check_spelling(self, msgid, line, line_num):
         original_line = line
-        if line.strip().startswith('#'):
+        if line.strip().startswith("#"):
             line = line.strip()[1:]
             starts_with_comment = True
         else:
@@ -266,8 +313,9 @@ class SpellingChecker(BaseTokenChecker):
                 if self.spelling_dict.check(word):
                     continue
             except enchant.errors.Error:
-                self.add_message('invalid-characters-in-docstring',
-                                 line=line_num, args=(word,))
+                self.add_message(
+                    "invalid-characters-in-docstring", line=line_num, args=(word,)
+                )
                 continue
 
             # Store word to private dict or raise a message.
@@ -278,7 +326,7 @@ class SpellingChecker(BaseTokenChecker):
             else:
                 # Present up to N suggestions.
                 suggestions = self.spelling_dict.suggest(word)
-                del suggestions[self.config.max_spelling_suggestions:]
+                del suggestions[self.config.max_spelling_suggestions :]
 
                 m = re.search(r"(\W|^)(%s)(\W|$)" % word, line)
                 if m:
@@ -291,10 +339,16 @@ class SpellingChecker(BaseTokenChecker):
                     col += 1
                 indicator = (" " * col) + ("^" * len(word))
 
-                self.add_message(msgid, line=line_num,
-                                 args=(word, original_line,
-                                       indicator,
-                                       "'{}'".format("' or '".join(suggestions))))
+                self.add_message(
+                    msgid,
+                    line=line_num,
+                    args=(
+                        word,
+                        original_line,
+                        indicator,
+                        "'{}'".format("' or '".join(suggestions)),
+                    ),
+                )
 
     def process_tokens(self, tokens):
         if not self.initialized:
@@ -303,28 +357,27 @@ class SpellingChecker(BaseTokenChecker):
         # Process tokens and look for comments.
         for (tok_type, token, (start_row, _), _, _) in tokens:
             if tok_type == tokenize.COMMENT:
-                if start_row == 1 and token.startswith('#!/'):
+                if start_row == 1 and token.startswith("#!/"):
                     # Skip shebang lines
                     continue
-                if token.startswith('# pylint:'):
+                if token.startswith("# pylint:"):
                     # Skip pylint enable/disable comments
                     continue
-                self._check_spelling('wrong-spelling-in-comment',
-                                     token, start_row)
+                self._check_spelling("wrong-spelling-in-comment", token, start_row)
 
-    @check_messages('wrong-spelling-in-docstring')
+    @check_messages("wrong-spelling-in-docstring")
     def visit_module(self, node):
         if not self.initialized:
             return
         self._check_docstring(node)
 
-    @check_messages('wrong-spelling-in-docstring')
+    @check_messages("wrong-spelling-in-docstring")
     def visit_classdef(self, node):
         if not self.initialized:
             return
         self._check_docstring(node)
 
-    @check_messages('wrong-spelling-in-docstring')
+    @check_messages("wrong-spelling-in-docstring")
     def visit_functiondef(self, node):
         if not self.initialized:
             return
@@ -342,8 +395,7 @@ class SpellingChecker(BaseTokenChecker):
 
         # Go through lines of docstring
         for idx, line in enumerate(docstring.splitlines()):
-            self._check_spelling('wrong-spelling-in-docstring',
-                                 line, start_line + idx)
+            self._check_spelling("wrong-spelling-in-docstring", line, start_line + idx)
 
 
 def register(linter):
