@@ -27,31 +27,20 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
 
-# pylint: disable=W0611
 """some functions that may be useful for various checkers
 """
 import builtins
-from functools import lru_cache, partial, singledispatch
+from functools import lru_cache, partial
 import itertools
 import numbers
 import re
 import sys
 import string
-from typing import (
-    Optional,
-    Iterable,
-    Tuple,
-    Callable,
-    Set,
-    Union,
-    Match,
-    Dict,
-    List,
-    Type,
-)
+from typing import Optional, Iterable, Tuple, Callable, Set, Union, Match, Dict, List
 import _string  # pylint: disable=wrong-import-position, wrong-import-order
 
 import astroid
+from astroid.exceptions import _NonDeducibleTypeHierarchy
 from astroid import bases as _bases
 from astroid import scoped_nodes
 
@@ -79,6 +68,7 @@ ITER_METHOD = "__iter__"
 AITER_METHOD = "__aiter__"
 NEXT_METHOD = "__next__"
 GETITEM_METHOD = "__getitem__"
+CLASS_GETITEM_METHOD = "__class_getitem__"
 SETITEM_METHOD = "__setitem__"
 DELITEM_METHOD = "__delitem__"
 CONTAINS_METHOD = "__contains__"
@@ -582,31 +572,31 @@ def parse_format_method_string(
 ) -> Tuple[List[Tuple[str, List[Tuple[bool, str]]]], int, int]:
     """
     Parses a PEP 3101 format string, returning a tuple of
-    (keys, num_args, manual_pos_arg),
-    where keys is the set of mapping keys in the format string, num_args
+    (keyword_arguments, implicit_pos_args_cnt, explicit_pos_args),
+    where keyword_arguments is the set of mapping keys in the format string, implicit_pos_args_cnt
     is the number of arguments required by the format string and
-    manual_pos_arg is the number of arguments passed with the position.
+    explicit_pos_args is the number of arguments passed with the position.
     """
-    keys = []
-    num_args = 0
-    manual_pos_arg = set()
+    keyword_arguments = []
+    implicit_pos_args_cnt = 0
+    explicit_pos_args = set()
     for name in collect_string_fields(format_string):
         if name and str(name).isdigit():
-            manual_pos_arg.add(str(name))
+            explicit_pos_args.add(str(name))
         elif name:
             keyname, fielditerator = split_format_field_names(name)
             if isinstance(keyname, numbers.Number):
                 # In Python 2 it will return long which will lead
                 # to different output between 2 and 3
-                manual_pos_arg.add(str(keyname))
+                explicit_pos_args.add(str(keyname))
                 keyname = int(keyname)
             try:
-                keys.append((keyname, list(fielditerator)))
+                keyword_arguments.append((keyname, list(fielditerator)))
             except ValueError:
                 raise IncompleteFormatString()
         else:
-            num_args += 1
-    return keys, num_args, len(manual_pos_arg)
+            implicit_pos_args_cnt += 1
+    return keyword_arguments, implicit_pos_args_cnt, len(explicit_pos_args)
 
 
 def is_attr_protected(attrname: str) -> bool:
@@ -1047,6 +1037,9 @@ def supports_membership_test(value: astroid.node_classes.NodeNG) -> bool:
 
 
 def supports_getitem(value: astroid.node_classes.NodeNG) -> bool:
+    if isinstance(value, astroid.ClassDef):
+        if _supports_protocol_method(value, CLASS_GETITEM_METHOD):
+            return True
     return _supports_protocol(value, _supports_getitem_protocol)
 
 
@@ -1210,6 +1203,9 @@ def is_subclass_of(child: astroid.ClassDef, parent: astroid.ClassDef) -> bool:
         return False
 
     for ancestor in child.ancestors():
-        if astroid.helpers.is_subtype(ancestor, parent):
-            return True
+        try:
+            if astroid.helpers.is_subtype(ancestor, parent):
+                return True
+        except _NonDeducibleTypeHierarchy:
+            continue
     return False
