@@ -135,24 +135,6 @@ def _merge_stats(stats):
     return merged
 
 
-@contextlib.contextmanager
-def _patch_sysmodules():
-    # Context manager that permits running pylint, on Windows, with -m switch
-    # and with --jobs, as in 'python -2 -m pylint .. --jobs'.
-    # For more details why this is needed,
-    # see Python issue http://bugs.python.org/issue10845.
-
-    mock_main = __name__ != "__main__"  # -m switch
-    if mock_main:
-        sys.modules["__main__"] = sys.modules[__name__]
-
-    try:
-        yield
-    finally:
-        if mock_main:
-            sys.modules.pop("__main__")
-
-
 # Python Linter class #########################################################
 
 MSGS = {
@@ -279,6 +261,10 @@ if multiprocessing is not None:
                 linter.load_plugin_modules(self._plugins)
 
             linter.load_configuration_from_config(self._config)
+
+            # Load plugin specific configuration
+            linter.load_plugin_configuration()
+
             linter.set_reporter(reporters.CollectingReporter())
 
             # Enable the Python 3 checker mode. This option is
@@ -650,6 +636,18 @@ class PyLinter(
             module = modutils.load_module_from_name(modname)
             module.register(self)
 
+    def load_plugin_configuration(self):
+        """Call the configuration hook for plugins
+
+        This walks through the list of plugins, grabs the "load_configuration"
+        hook, if exposed, and calls it to allow plugins to configure specific
+        settings.
+        """
+        for modname in self._dynamic_plugins:
+            module = modutils.load_module_from_name(modname)
+            if hasattr(module, "load_configuration"):
+                module.load_configuration(self)
+
     def _load_reporter(self):
         name = self._reporter_name.lower()
         if name in self._reporters:
@@ -736,7 +734,7 @@ class PyLinter(
             self.register_report(r_id, r_title, r_cb, checker)
         self.register_options_provider(checker)
         if hasattr(checker, "msgs"):
-            self.msgs_store.register_messages(checker)
+            self.msgs_store.register_messages_from_checker(checker)
         checker.load_defaults()
 
         # Register the checker, but disable all of its messages.
@@ -880,6 +878,13 @@ class PyLinter(
             if c is not self
         ]
 
+    def get_checker_names(self):
+        """Get all the checker names that this linter knows about."""
+        current_checkers = self.get_checkers()
+        return sorted(
+            {check.name for check in current_checkers if check.name != "master"}
+        )
+
     def prepare_checkers(self):
         """return checkers needed for activated messages and reports"""
         if not self.config.reports:
@@ -937,8 +942,7 @@ class PyLinter(
         if self.config.jobs == 1:
             self._do_check(files_or_modules)
         else:
-            with _patch_sysmodules():
-                self._parallel_check(files_or_modules)
+            self._parallel_check(files_or_modules)
 
     def _get_jobs_config(self):
         child_config = collections.OrderedDict()
@@ -1437,6 +1441,17 @@ group are mutually exclusive.",
                         "help": "Generate pylint's messages.",
                     },
                 ),
+                (
+                    "list-groups",
+                    {
+                        "action": "callback",
+                        "metavar": "<msg-id>",
+                        "callback": self.cb_list_groups,
+                        "group": "Commands",
+                        "level": 1,
+                        "help": "List pylint's message groups.",
+                    },
+                ),
                 (
                     "list-conf-levels",
                     {
@@ -1569,6 +1584,7 @@ group are mutually exclusive.",
         # now we can load file config and command line, plugins (which can
         # provide options) have been registered
         linter.load_config_file()
+
         if reporter:
             # if a custom reporter is provided as argument, it may be overridden
             # by file parameters, so re-set it here, but before command line
@@ -1602,6 +1618,10 @@ group are mutually exclusive.",
                 if linter.config.jobs == 0:
                     linter.config.jobs = _cpu_count()
 
+        # We have loaded configuration from config file and command line. Now, we can
+        # load plugin specific configuration.
+        linter.load_plugin_configuration()
+
         # insert current working directory to the python path to have a correct
         # behaviour
         with fix_import_path(args):
@@ -1658,6 +1678,16 @@ group are mutually exclusive.",
         self.linter.msgs_store.list_messages()
         sys.exit(0)
 
+    def cb_list_groups(self, *args, **kwargs):
+        """List all the check groups that pylint knows about
+
+        These should be useful to know what check groups someone can disable
+        or enable.
+        """
+        for check in self.linter.get_checker_names():
+            print(check)
+        sys.exit(0)
+
     def cb_python3_porting_mode(self, *args, **kwargs):
         """Activate only the python3 porting checker."""
         self.linter.python3_porting_mode()
