@@ -17,22 +17,24 @@ from pylint.pyreverse.utils import is_exception
 from pylint.pyreverse.vcgutils import VCGPrinter
 from pylint.graph import DotBackend
 
+
 class DiagramWriter:
     """base class for writing project diagrams
     """
+
     def __init__(self, config, styles):
         self.config = config
-        self.pkg_edges, self.inh_edges, self.imp_edges, self.ass_edges = styles
-        self.printer = None # defined in set_printer
+        self.pkg_edges, self.inh_edges, self.imp_edges, self.association_edges = styles
+        self.printer = None  # defined in set_printer
 
     def write(self, diadefs):
         """write files for <project> according to <diadefs>
         """
         for diagram in diadefs:
-            basename = diagram.title.strip().replace(' ', '_')
-            file_name = '%s.%s' % (basename, self.config.output_format)
+            basename = diagram.title.strip().replace(" ", "_")
+            file_name = "%s.%s" % (basename, self.config.output_format)
             self.set_printer(file_name, basename)
-            if diagram.TYPE == 'class':
+            if diagram.TYPE == "class":
                 self.write_classes(diagram)
             else:
                 self.write_packages(diagram)
@@ -42,12 +44,13 @@ class DiagramWriter:
         """write a package diagram"""
         # sorted to get predictable (hence testable) results
         for i, obj in enumerate(sorted(diagram.modules(), key=lambda x: x.title)):
-            self.printer.emit_node(i, label=self.get_title(obj), shape='box')
+            self.printer.emit_node(i, label=self.get_title(obj), shape="box")
             obj.fig_id = i
         # package dependencies
-        for rel in diagram.get_relationships('depends'):
-            self.printer.emit_edge(rel.from_object.fig_id, rel.to_object.fig_id,
-                                   **self.pkg_edges)
+        for rel in diagram.get_relationships("depends"):
+            self.printer.emit_edge(
+                rel.from_object.fig_id, rel.to_object.fig_id, **self.pkg_edges
+            )
 
     def write_classes(self, diagram):
         """write a class diagram"""
@@ -56,17 +59,23 @@ class DiagramWriter:
             self.printer.emit_node(i, **self.get_values(obj))
             obj.fig_id = i
         # inheritance links
-        for rel in diagram.get_relationships('specialization'):
-            self.printer.emit_edge(rel.from_object.fig_id, rel.to_object.fig_id,
-                                   **self.inh_edges)
+        for rel in diagram.get_relationships("specialization"):
+            self.printer.emit_edge(
+                rel.from_object.fig_id, rel.to_object.fig_id, **self.inh_edges
+            )
         # implementation links
-        for rel in diagram.get_relationships('implements'):
-            self.printer.emit_edge(rel.from_object.fig_id, rel.to_object.fig_id,
-                                   **self.imp_edges)
+        for rel in diagram.get_relationships("implements"):
+            self.printer.emit_edge(
+                rel.from_object.fig_id, rel.to_object.fig_id, **self.imp_edges
+            )
         # generate associations
-        for rel in diagram.get_relationships('association'):
-            self.printer.emit_edge(rel.from_object.fig_id, rel.to_object.fig_id,
-                                   label=rel.name, **self.ass_edges)
+        for rel in diagram.get_relationships("association"):
+            self.printer.emit_edge(
+                rel.from_object.fig_id,
+                rel.to_object.fig_id,
+                label=rel.name,
+                **self.association_edges
+            )
 
     def set_printer(self, file_name, basename):
         """set printer"""
@@ -90,12 +99,14 @@ class DotWriter(DiagramWriter):
     """
 
     def __init__(self, config):
-        styles = [dict(arrowtail='none', arrowhead="open"),
-                  dict(arrowtail='none', arrowhead='empty'),
-                  dict(arrowtail='node', arrowhead='empty', style='dashed'),
-                  dict(fontcolor='green', arrowtail='none',
-                       arrowhead='diamond', style='solid'),
-                 ]
+        styles = [
+            dict(arrowtail="none", arrowhead="open"),
+            dict(arrowtail="none", arrowhead="empty"),
+            dict(arrowtail="node", arrowhead="empty", style="dashed"),
+            dict(
+                fontcolor="green", arrowtail="none", arrowhead="diamond", style="solid"
+            ),
+        ]
         DiagramWriter.__init__(self, config, styles)
 
     def set_printer(self, file_name, basename):
@@ -115,16 +126,16 @@ class DotWriter(DiagramWriter):
         The label contains all attributes and methods
         """
         label = obj.title
-        if obj.shape == 'interface':
-            label = '«interface»\\n%s' % label
+        if obj.shape == "interface":
+            label = "«interface»\\n%s" % label
         if not self.config.only_classnames:
-            label = r'%s|%s\l|' % (label, r'\l'.join(obj.attrs))
+            label = r"%s|%s\l|" % (label, r"\l".join(obj.attrs))
             for func in obj.methods:
-                label = r'%s%s()\l' % (label, func.name)
-            label = '{%s}' % label
+                label = r"%s%s()\l" % (label, func.name)
+            label = "{%s}" % label
         if is_exception(obj.node):
-            return dict(fontcolor='red', label=label, shape='record')
-        return dict(label=label, shape='record')
+            return dict(fontcolor="red", label=label, shape="record")
+        return dict(label=label, shape="record")
 
     def close_graph(self):
         """print the dot graph into <file_name>"""
@@ -134,31 +145,38 @@ class DotWriter(DiagramWriter):
 class VCGWriter(DiagramWriter):
     """write vcg graphs from a diagram definition and a project
     """
+
     def __init__(self, config):
-        styles = [dict(arrowstyle='solid', backarrowstyle='none',
-                       backarrowsize=0),
-                  dict(arrowstyle='solid', backarrowstyle='none',
-                       backarrowsize=10),
-                  dict(arrowstyle='solid', backarrowstyle='none',
-                       linestyle='dotted', backarrowsize=10),
-                  dict(arrowstyle='solid', backarrowstyle='none',
-                       textcolor='green'),
-                 ]
+        styles = [
+            dict(arrowstyle="solid", backarrowstyle="none", backarrowsize=0),
+            dict(arrowstyle="solid", backarrowstyle="none", backarrowsize=10),
+            dict(
+                arrowstyle="solid",
+                backarrowstyle="none",
+                linestyle="dotted",
+                backarrowsize=10,
+            ),
+            dict(arrowstyle="solid", backarrowstyle="none", textcolor="green"),
+        ]
         DiagramWriter.__init__(self, config, styles)
 
     def set_printer(self, file_name, basename):
         """initialize VCGWriter for a UML graph"""
-        self.graph_file = open(file_name, 'w+')
+        self.graph_file = open(file_name, "w+")
         self.printer = VCGPrinter(self.graph_file)
-        self.printer.open_graph(title=basename, layoutalgorithm='dfs',
-                                late_edge_labels='yes', port_sharing='no',
-                                manhattan_edges='yes')
+        self.printer.open_graph(
+            title=basename,
+            layoutalgorithm="dfs",
+            late_edge_labels="yes",
+            port_sharing="no",
+            manhattan_edges="yes",
+        )
         self.printer.emit_node = self.printer.node
         self.printer.emit_edge = self.printer.edge
 
     def get_title(self, obj):
         """get project title in vcg format"""
-        return r'\fb%s\fn' % obj.title
+        return r"\fb%s\fn" % obj.title
 
     def get_values(self, obj):
         """get label and shape for classes.
@@ -166,26 +184,26 @@ class VCGWriter(DiagramWriter):
         The label contains all attributes and methods
         """
         if is_exception(obj.node):
-            label = r'\fb\f09%s\fn' % obj.title
+            label = r"\fb\f09%s\fn" % obj.title
         else:
-            label = r'\fb%s\fn' % obj.title
-        if obj.shape == 'interface':
-            shape = 'ellipse'
+            label = r"\fb%s\fn" % obj.title
+        if obj.shape == "interface":
+            shape = "ellipse"
         else:
-            shape = 'box'
+            shape = "box"
         if not self.config.only_classnames:
             attrs = obj.attrs
             methods = [func.name for func in obj.methods]
             # box width for UML like diagram
             maxlen = max(len(name) for name in [obj.title] + methods + attrs)
-            line = '_' * (maxlen + 2)
-            label = r'%s\n\f%s' % (label, line)
+            line = "_" * (maxlen + 2)
+            label = r"%s\n\f%s" % (label, line)
             for attr in attrs:
-                label = r'%s\n\f08%s' % (label, attr)
+                label = r"%s\n\f08%s" % (label, attr)
             if attrs:
-                label = r'%s\n\f%s' % (label, line)
+                label = r"%s\n\f%s" % (label, line)
             for func in methods:
-                label = r'%s\n\f10%s()' % (label, func)
+                label = r"%s\n\f10%s()" % (label, func)
         return dict(label=label, shape=shape)
 
     def close_graph(self):
