@@ -11,13 +11,15 @@ from __future__ import print_function
 from pylint.reporters.ureports import BaseWriter
 
 
-TITLE_UNDERLINES = ['', '=', '-', '`', '.', '~', '^']
-BULLETS = ['*', '-']
+TITLE_UNDERLINES = ["", "=", "-", "`", ".", "~", "^"]
+BULLETS = ["*", "-"]
+
 
 class TextWriter(BaseWriter):
     """format layouts as text
     (ReStructured inspiration but not totally handled yet)
     """
+
     def begin_format(self):
         super(TextWriter, self).begin_format()
         self.list_level = 0
@@ -39,7 +41,7 @@ class TextWriter(BaseWriter):
         self.writeln()
 
     def visit_title(self, layout):
-        title = ''.join(list(self.compute_content(layout)))
+        title = "".join(list(self.compute_content(layout)))
         self.writeln(title)
         try:
             self.writeln(TITLE_UNDERLINES[self.section] * len(title))
@@ -55,7 +57,7 @@ class TextWriter(BaseWriter):
         """display a table as text"""
         table_content = self.get_table_content(layout)
         # get columns width
-        cols_width = [0]*len(table_content[0])
+        cols_width = [0] * len(table_content[0])
         for row in table_content:
             for index, col in enumerate(row):
                 cols_width[index] = max(cols_width[index], len(col))
@@ -64,19 +66,19 @@ class TextWriter(BaseWriter):
 
     def default_table(self, layout, table_content, cols_width):
         """format a table"""
-        cols_width = [size+1 for size in cols_width]
-        format_strings = ' '.join(['%%-%ss'] * len(cols_width))
+        cols_width = [size + 1 for size in cols_width]
+        format_strings = " ".join(["%%-%ss"] * len(cols_width))
         format_strings = format_strings % tuple(cols_width)
-        format_strings = format_strings.split(' ')
-        table_linesep = '\n+' + '+'.join(['-'*w for w in cols_width]) + '+\n'
-        headsep = '\n+' + '+'.join(['='*w for w in cols_width]) + '+\n'
+        format_strings = format_strings.split(" ")
+        table_linesep = "\n+" + "+".join(["-" * w for w in cols_width]) + "+\n"
+        headsep = "\n+" + "+".join(["=" * w for w in cols_width]) + "+\n"
         # FIXME: layout.cheaders
         self.write(table_linesep)
         for index, line in enumerate(table_content):
-            self.write('|')
+            self.write("|")
             for line_index, at_index in enumerate(line):
                 self.write(format_strings[line_index] % at_index)
-                self.write('|')
+                self.write("|")
             if index == 0 and layout.rheaders:
                 self.write(headsep)
             else:
@@ -85,11 +87,11 @@ class TextWriter(BaseWriter):
     def visit_verbatimtext(self, layout):
         """display a verbatim layout as text (so difficult ;)
         """
-        self.writeln('::\n')
+        self.writeln("::\n")
         for line in layout.data.splitlines():
-            self.writeln('    ' + line)
+            self.writeln("    " + line)
         self.writeln()
 
     def visit_text(self, layout):
         """add some text"""
-        self.write('%s' % layout.data)
+        self.write("%s" % layout.data)
