@@ -27,13 +27,13 @@ def _process_classes(classes):
     """extract class names of a list"""
     return sorted([(isinstance(c.node, astroid.ClassDef), c.title) for c in classes])
 
+
 def _process_relations(relations):
     """extract relation indices from a relation list"""
     result = []
     for rel_type, rels in relations.items():
         for rel in rels:
-            result.append( (rel_type, rel.from_object.title,
-                            rel.to_object.title) )
+            result.append((rel_type, rel.from_object.title, rel.to_object.title))
     result.sort()
     return result
 
@@ -43,17 +43,17 @@ def HANDLER():
     return DiadefsHandler(Config())
 
 
-@pytest.fixture(scope='module')
+@pytest.fixture(scope="module")
 def PROJECT():
-    return get_project('data')
+    return get_project("data")
 
 
 def test_option_values(HANDLER, PROJECT):
     """test for ancestor, associated and module options"""
     df_h = DiaDefGenerator(Linker(PROJECT), HANDLER)
     cl_config = Config()
-    cl_config.classes = ['Specialization']
-    cl_h = DiaDefGenerator(Linker(PROJECT), DiadefsHandler(cl_config) )
+    cl_config.classes = ["Specialization"]
+    cl_h = DiaDefGenerator(Linker(PROJECT), DiadefsHandler(cl_config))
     assert (0, 0) == df_h._get_levels()
     assert False == df_h.module_names
     assert (-1, -1) == cl_h._get_levels()
@@ -65,11 +65,11 @@ def test_option_values(HANDLER, PROJECT):
         hndl._set_default_options()
         assert (-1, -1) == hndl._get_levels()
         assert True == hndl.module_names
-    handler = DiadefsHandler( Config())
+    handler = DiadefsHandler(Config())
     df_h = DiaDefGenerator(Linker(PROJECT), handler)
     cl_config = Config()
-    cl_config.classes = ['Specialization']
-    cl_h = DiaDefGenerator(Linker(PROJECT), DiadefsHandler(cl_config) )
+    cl_config.classes = ["Specialization"]
+    cl_h = DiaDefGenerator(Linker(PROJECT), DiadefsHandler(cl_config))
     for hndl in [df_h, cl_h]:
         hndl.config.show_ancestors = 2
         hndl.config.show_associated = 1
@@ -78,36 +78,45 @@ def test_option_values(HANDLER, PROJECT):
         assert (2, 1) == hndl._get_levels()
         assert False == hndl.module_names
 
-#def test_default_values():
+    # def test_default_values():
     """test efault values for package or class diagrams"""
     # TODO : should test difference between default values for package
     # or class diagrams
 
+
 class TestDefaultDiadefGenerator(object):
     def test_known_values1(self, HANDLER, PROJECT):
         dd = DefaultDiadefGenerator(Linker(PROJECT), HANDLER).visit(PROJECT)
         assert len(dd) == 2
         keys = [d.TYPE for d in dd]
-        assert keys == ['package', 'class']
+        assert keys == ["package", "class"]
         pd = dd[0]
-        assert pd.title == 'packages No Name'
-        modules = sorted([(isinstance(m.node, astroid.Module), m.title)
-                         for m in pd.objects])
-        assert modules == [(True, 'data'),
-                           (True, 'data.clientmodule_test'),
-                           (True, 'data.suppliermodule_test')]
+        assert pd.title == "packages No Name"
+        modules = sorted(
+            [(isinstance(m.node, astroid.Module), m.title) for m in pd.objects]
+        )
+        assert modules == [
+            (True, "data"),
+            (True, "data.clientmodule_test"),
+            (True, "data.suppliermodule_test"),
+        ]
         cd = dd[1]
-        assert cd.title == 'classes No Name'
+        assert cd.title == "classes No Name"
         classes = _process_classes(cd.objects)
-        assert classes == [(True, 'Ancestor'),
-                           (True, 'DoNothing'),
-                           (True, 'Interface'),
-                           (True, 'Specialization')]
+        assert classes == [
+            (True, "Ancestor"),
+            (True, "DoNothing"),
+            (True, "Interface"),
+            (True, "Specialization"),
+        ]
+
+    _should_rels = [
+        ("association", "DoNothing", "Ancestor"),
+        ("association", "DoNothing", "Specialization"),
+        ("implements", "Ancestor", "Interface"),
+        ("specialization", "Specialization", "Ancestor"),
+    ]
 
-    _should_rels = [('association', 'DoNothing', 'Ancestor'),
-                    ('association', 'DoNothing', 'Specialization'),
-                    ('implements', 'Ancestor', 'Interface'),
-                    ('specialization', 'Specialization', 'Ancestor')]
     def test_exctract_relations(self, HANDLER, PROJECT):
         """test extract_relations between classes"""
         cd = DefaultDiadefGenerator(Linker(PROJECT), HANDLER).visit(PROJECT)[1]
@@ -120,44 +129,49 @@ class TestDefaultDiadefGenerator(object):
         different classes possibly in different modules"""
         # XXX should be catching pyreverse environnement problem but doesn't
         # pyreverse doesn't extracts the relations but this test ok
-        project = get_project('data')
+        project = get_project("data")
         handler = DiadefsHandler(Config())
-        diadefs = handler.get_diadefs(project, Linker(project, tag=True) )
+        diadefs = handler.get_diadefs(project, Linker(project, tag=True))
         cd = diadefs[1]
         relations = _process_relations(cd.relationships)
         assert relations == self._should_rels
 
     def test_known_values2(self, HANDLER):
-        project = get_project('data.clientmodule_test')
+        project = get_project("data.clientmodule_test")
         dd = DefaultDiadefGenerator(Linker(project), HANDLER).visit(project)
         assert len(dd) == 1
         keys = [d.TYPE for d in dd]
-        assert keys == ['class']
+        assert keys == ["class"]
         cd = dd[0]
-        assert cd.title == 'classes No Name'
+        assert cd.title == "classes No Name"
         classes = _process_classes(cd.objects)
-        assert classes == [(True, 'Ancestor'),
-                           (True, 'Specialization')]
+        assert classes == [(True, "Ancestor"), (True, "Specialization")]
 
 
 def test_known_values1(HANDLER, PROJECT):
-    HANDLER.config.classes = ['Specialization']
+    HANDLER.config.classes = ["Specialization"]
     cdg = ClassDiadefGenerator(Linker(PROJECT), HANDLER)
-    special = 'data.clientmodule_test.Specialization'
+    special = "data.clientmodule_test.Specialization"
     cd = cdg.class_diagram(PROJECT, special)
     assert cd.title == special
     classes = _process_classes(cd.objects)
-    assert classes == [(True, 'data.clientmodule_test.Ancestor'),
-                       (True, special),
-                       (True, 'data.suppliermodule_test.DoNothing')]
+    assert classes == [
+        (True, "data.clientmodule_test.Ancestor"),
+        (True, special),
+        (True, "data.suppliermodule_test.DoNothing"),
+    ]
 
 
 def test_known_values2(HANDLER, PROJECT):
-    HANDLER.config.classes = ['Specialization']
+    HANDLER.config.classes = ["Specialization"]
     HANDLER.config.module_names = False
-    cd = ClassDiadefGenerator(Linker(PROJECT), HANDLER).class_diagram(PROJECT, 'data.clientmodule_test.Specialization')
-    assert cd.title == 'data.clientmodule_test.Specialization'
+    cd = ClassDiadefGenerator(Linker(PROJECT), HANDLER).class_diagram(
+        PROJECT, "data.clientmodule_test.Specialization"
+    )
+    assert cd.title == "data.clientmodule_test.Specialization"
     classes = _process_classes(cd.objects)
-    assert classes == [(True, 'Ancestor'),
-                       (True, 'DoNothing'),
-                       (True, 'Specialization')]
+    assert classes == [
+        (True, "Ancestor"),
+        (True, "DoNothing"),
+        (True, "Specialization"),
+    ]
